# Torch Utilities

- Dataset utilities
- Distribution
- Model parameter freezing
- Image tensor channels conversions
- Baseline model parameter initialisations
- Optimisation learning rate schedulers
- Model persistence
- Tensor tooling, creation, normalisation, reshaping...
- Model parameter cloning and soft-updates
- Cuda device tooling, automatic selection of target compute device and global handle
